"""
Handles /sms-webhooks endpoint
"""

import requests
from mailersend.base import base


class NewSmsWebhooks(base.NewAPIClient):
    """
    Instantiates the /sms-webhooks endpoint object
    """

    # you shall not
    pass

    def get_webhooks(self, sms_number_id):
        """
        Get a list of SMS webhooks.

        @params:
          sms_number_id (string)
        """

        passed_arguments = locals()
        query_params = {
            "sms_number_id": sms_number_id
        }

        request = requests.get(
            f"{self.api_base}/sms-webhooks", headers=self.headers_default, params=query_params
        )

        return f"{request.status_code}\n{request.text}"

    def get_webhook(self, sms_webhook_id):
        """
        Get a single SMS webhook.

        @params:
          sms_webhook_id (string)
        """

        request = requests.get(
            f"{self.api_base}/sms-webhooks/{sms_webhook_id}", headers=self.headers_default
        )

        return f"{request.status_code}\n{request.text}"

    def create_webhook(self, url, name, events, sms_number_id, enabled=True):
        """
        Create an SMS webhook.

        @params:
          url (string)
          name (string)
          events (dict)
          enabled (bool)
          sms_number_id (string)
        """

        data = {
            "url": url,
            "name": name,
            "events": events,
            "sms_number_id": sms_number_id,
            "enabled": int(enabled)
        }

        request = requests.post(
            f"{self.api_base}/sms-webhooks", headers=self.headers_default, json=data
        )

        return f"{request.status_code}\n{request.text}"

    def update_webhook(self, sms_webhook_id, url=None, name=None, events=None, enabled=None):
        """
        Update a single SMS Webhook.

        @params:
          sms_webhook_id (string)
          url (string)
          name (string)
          events (dict)
          enabled (bool)
        """

        passed_arguments = locals()
        data = {}

        for key, value in passed_arguments.items():
            if key != "self" and key != "sms_webhook_id" and value is not None:
                if key == "enabled":
                    data[key] = int(value)
                else:
                    data[key] = value

        request = requests.put(
            f"{self.api_base}/sms-webhooks/{sms_webhook_id}", headers=self.headers_default, json=data
        )

        return f"{request.status_code}\n{request.text}"

    def delete_webhook(self, sms_webhook_id):
        """
        Delete an SMS webhook.

        @params:
          sms_webhook_id (string)
        """

        request = requests.delete(
            f"{self.api_base}/sms-webhooks/{sms_webhook_id}", headers=self.headers_default
        )

        return f"{request.status_code}\n{request.text}"



"""
Handles /sms-messages endpoint
"""

import requests
from mailersend.base import base


class NewSmsMessages(base.NewAPIClient):
    """
    Instantiates the /sms-messages endpoint object
    """

    pass

    def get_messages(self, page=1, limit=25):
        """
        Get a list of SMS messages.

        @params:
          page (int)
          limit (int): Min: `10`, Max: `100`, default is 25
        """

        passed_arguments = locals()
        query_params = {}

        for key, value in passed_arguments.items():
            query_params[key] = value

        request = requests.get(
            f"{self.api_base}/sms-messages", headers=self.headers_default, params=query_params
        )

        return f"{request.status_code}\n{request.text}"

    def get_message(self, sms_message_id):
        """
        Get a single SMS message.

        @params:
          sms_message_id (string)
        """

        request = requests.get(
            f"{self.api_base}/sms-messages/{sms_message_id}", headers=self.headers_default
        )

        return f"{request.status_code}\n{request.text}"






"""
Handles /sms-numbers endpoint
"""

import requests
from mailersend.base import base


class NewSmsNumbers(base.NewAPIClient):
    """
    Instantiates the /sms-numbers endpoint object
    """

    pass

    def get_phone_numbers(self, paused=False, page=None, limit=25):
        """
        Get a list of SMS phone numbers information.

        @params:
          paused (bool)
          page (int)
          limit (int): Min: `10`, Max: `100`, default is 25
        """

        passed_arguments = locals()
        query_params = {}

        for key, value in passed_arguments.items():
            if key != "self":
                if key == "paused":
                    query_params[key] = int(value)
                else:
                    query_params[key] = value

        request = requests.get(
            f"{self.api_base}/sms-numbers", headers=self.headers_default, params=query_params
        )

        return f"{request.status_code}\n{request.text}"

    def get_phone_number(self, sms_number_id):
        """
        Get information about a specific SMS phone number

        @params:
          sms_number_id (string)
        """

        request = requests.get(
            f"{self.api_base}/sms-numbers/{sms_number_id}", headers=self.headers_default
        )

        return f"{request.status_code}\n{request.text}"

    def update_phone_number(self, sms_number_id, paused=True):
        """
        Update a specific SMS phone number

        @params:
          sms_number_id (string)
           paused (bool)
        """

        query_params = {
            "paused": int(paused)
        }
        data = {"sms_number_id": sms_number_id}

        request = requests.put(
            f"{self.api_base}/sms-numbers/{sms_number_id}", headers=self.headers_default, params=query_params, json=data
        )

        return f"{request.status_code}\n{request.text}"

    def delete_phone_number(self, sms_number_id):
        """
        Delete a specific SMS phone number

        @params:
          sms_number_id (string)
        """

        data = {"sms_number_id": sms_number_id}

        request = requests.delete(
            f"{self.api_base}/sms-numbers/{sms_number_id}", headers=self.headers_default, json=data
        )

        return f"{request.status_code}\n{request.text}"



"""
Handles /sms-recipients endpoint
"""

import requests
from mailersend.base import base


class NewSmsRecipients(base.NewAPIClient):
    """
    Instantiates the /sms-recipients endpoint object
    """

    pass

    def get_recipients(self, status="active", sms_number_id=None, page=None, limit=25):
        """
        Get information about SMS recipients.

        @params:
          status (string) - Possible values are `active` and `opt_out`
          sms_number_id (string)
          page (int)
          limit (int): Min: `10`, Max: `100`, default is 25
        """

        passed_arguments = locals()
        query_params = {}

        for key, value in passed_arguments.items():
            if key != "self":
                query_params[key] = value

        request = requests.get(
            f"{self.api_base}/sms-recipients", headers=self.headers_default, params=query_params
        )

        return f"{request.status_code}\n{request.text}"

    def get_recipient(self, sms_recipient_id):
        """
        Get information about a specific SMS recipient.

        @params:
          sms_recipient_id (string) - Possible values are `active` and `opt_out`
        """

        request = requests.get(
            f"{self.api_base}/sms-recipients/{sms_recipient_id}", headers=self.headers_default
        )

        return f"{request.status_code}\n{request.text}"

    def update_recipient(self, sms_recipient_id, status):
        """
        Update a specific SMS recipient

        @params:
          sms_recipient_id (string)
          status (string)
        """

        query_params = {
            "status": status
        }
        data = {"sms_recipient_id": sms_recipient_id}

        request = requests.put(
            f"{self.api_base}/sms-recipients/{sms_recipient_id}",
            headers=self.headers_default, params=query_params, json=data
        )

        return f"{request.status_code}\n{request.text}"

